matrix_from_gauss_with_segments

Function matrix_from_gauss_with_segments 

pub fn matrix_from_gauss_with_segments<T, K, H>(
    kernel: &K,
    gauss_x: &Rule<T>,
    gauss_y: &Rule<T>,
    symmetry: SymmetryType,
    hints: &H,
) -> DiscretizedKernel<T>
Compute matrix from Gauss quadrature rules with segments from SVEHints

This function evaluates the kernel at all combinations of Gauss points and returns a DiscretizedKernel containing the matrix, quadrature rules, and segments.