init_fpu_check

Function init_fpu_check 

pub fn init_fpu_check()
Initialize FPU check (call this early to trigger warning if needed)

This function triggers the lazy initialization which checks FPU state and prints a warning if dangerous settings are detected. The warning is only printed once per process.