pub struct Rule<T> { /* private fields */ }Expand description
Quadrature rule for numerical integration.
Represents an approximation of an integral by a weighted sum over discrete points.
The rule contains quadrature points x, weights w, and auxiliary arrays
x_forward and x_backward for efficient computation.
Implementations
Sourceimpl<T> Rule<T>where
T: Copy,
impl<T> Rule<T>where
T: Copy,
Sourcepub fn x_backward(&self) -> &[T]
pub fn x_backward(&self) -> &[T]
Distance of each point from the right endpoint: b - x
Sourceimpl<T> Rule<T>where
T: CustomNumeric,
impl<T> Rule<T>where
T: CustomNumeric,
Sourcepub fn new(x: Vec<T>, w: Vec<T>, a: T, b: T) -> Result<Rule<T>, Error>
pub fn new(x: Vec<T>, w: Vec<T>, a: T, b: T) -> Result<Rule<T>, Error>
Create a new quadrature rule from points and weights.
Arguments
x- Quadrature pointsw- Quadrature weightsa- Left endpoint (default: -1.0)b- Right endpoint (default: 1.0)
The points are not checked for order or for lying in [a, b];
Self::validate does that.
Errors
Error::InvalidParameter if x and w have different lengths.
Sourcepub fn reseat(&self, a: T, b: T) -> Rule<T>
pub fn reseat(&self, a: T, b: T) -> Rule<T>
Reseat the rule to a new interval [a, b].
Scales and translates the quadrature points and weights to the new interval.
Sourcepub fn piecewise(&self, edges: &[T]) -> Result<Rule<T>, Error>
pub fn piecewise(&self, edges: &[T]) -> Result<Rule<T>, Error>
Create a piecewise rule over multiple segments.
Arguments
edges- Segment boundaries: at least 2, finite and strictly increasing, with finite segment lengths and a finite sum of the ends of each segment (the midpoint of the segment is computed from it)
Errors
Error::InvalidParameter if edges does not meet these conditions
Sourceimpl<T> Rule<T>where
T: CustomNumeric,
CustomNumeric-based implementation for f64 and Df64 support
impl<T> Rule<T>where
T: CustomNumeric,
CustomNumeric-based implementation for f64 and Df64 support
Sourcepub fn new_custom(x: Vec<T>, w: Vec<T>, a: T, b: T) -> Result<Rule<T>, Error>
pub fn new_custom(x: Vec<T>, w: Vec<T>, a: T, b: T) -> Result<Rule<T>, Error>
Create a new quadrature rule from points and weights (CustomNumeric version).
Errors
Error::InvalidParameter if x and w have different lengths.
Sourcepub fn from_vectors_custom(
x: Vec<T>,
w: Vec<T>,
a: T,
b: T,
) -> Result<Rule<T>, Error>
pub fn from_vectors_custom( x: Vec<T>, w: Vec<T>, a: T, b: T, ) -> Result<Rule<T>, Error>
Create a new quadrature rule from vectors (CustomNumeric version).
Errors
The errors of Self::new_custom.
Sourcepub fn reseat_custom(&self, a: T, b: T) -> Rule<T>
pub fn reseat_custom(&self, a: T, b: T) -> Rule<T>
Reseat the rule to a new interval [a, b] (CustomNumeric version).
Sourcepub fn scale_custom(&self, factor: T) -> Rule<T>
pub fn scale_custom(&self, factor: T) -> Rule<T>
Scale the weights by a factor (CustomNumeric version).
Sourcepub fn validate_custom(&self) -> bool
pub fn validate_custom(&self) -> bool
Validate the rule for consistency (CustomNumeric version).
Sourceimpl Rule<Compensated<f64, f64>>
Df64-specific implementation without ScalarOperand requirement
impl Rule<Compensated<f64, f64>>
Df64-specific implementation without ScalarOperand requirement
Sourcepub fn new_twofloat(
x: Vec<Compensated<f64, f64>>,
w: Vec<Compensated<f64, f64>>,
a: Compensated<f64, f64>,
b: Compensated<f64, f64>,
) -> Result<Rule<Compensated<f64, f64>>, Error>
pub fn new_twofloat( x: Vec<Compensated<f64, f64>>, w: Vec<Compensated<f64, f64>>, a: Compensated<f64, f64>, b: Compensated<f64, f64>, ) -> Result<Rule<Compensated<f64, f64>>, Error>
Create a new quadrature rule from points and weights (Df64 version).
Errors
Error::InvalidParameter if x and w have different lengths.
Sourcepub fn from_vectors_twofloat(
x: Vec<Compensated<f64, f64>>,
w: Vec<Compensated<f64, f64>>,
a: Compensated<f64, f64>,
b: Compensated<f64, f64>,
) -> Result<Rule<Compensated<f64, f64>>, Error>
pub fn from_vectors_twofloat( x: Vec<Compensated<f64, f64>>, w: Vec<Compensated<f64, f64>>, a: Compensated<f64, f64>, b: Compensated<f64, f64>, ) -> Result<Rule<Compensated<f64, f64>>, Error>
Sourcepub fn reseat_twofloat(
&self,
a: Compensated<f64, f64>,
b: Compensated<f64, f64>,
) -> Rule<Compensated<f64, f64>>
pub fn reseat_twofloat( &self, a: Compensated<f64, f64>, b: Compensated<f64, f64>, ) -> Rule<Compensated<f64, f64>>
Reseat the rule to a new interval [a, b] (Df64 version).
Sourcepub fn scale_twofloat(
&self,
factor: Compensated<f64, f64>,
) -> Rule<Compensated<f64, f64>>
pub fn scale_twofloat( &self, factor: Compensated<f64, f64>, ) -> Rule<Compensated<f64, f64>>
Scale the weights by a factor (Df64 version).
Sourcepub fn validate_twofloat(&self) -> bool
pub fn validate_twofloat(&self) -> bool
Validate the rule for consistency (Df64 version).