pub struct LogisticKernel { /* private fields */ }Expand description
Logistic kernel for fermionic and bosonic analytical continuation
For bosons the spectral function is divided by the regularizer tanh(βω/2).
This kernel implements K(x, y) = exp(-Λy(x + 1)/2)/(1 + exp(-Λy)) where x ∈ [-1, 1] and y ∈ [-1, 1]
Implementations
Sourceimpl LogisticKernel
impl LogisticKernel
Sourcepub fn new(lambda: f64) -> Result<LogisticKernel, Error>
pub fn new(lambda: f64) -> Result<LogisticKernel, Error>
Create a new logistic kernel with the given cutoff parameter
Arguments
lambda- Kernel cutoff Λ = β ωmax, positive and finite. The SVE grid, and the memory it needs, grows with Λ.
Errors
Error::InvalidParameter if lambda is not positive and finite