spherical_bessel_j

Function spherical_bessel_j 

pub fn spherical_bessel_j(n: i32, x: f64) -> f64
Main function to calculate spherical Bessel function of the first kind

This is the main entry point that matches the C++ sphericalbesselj function