pub struct PiecewiseLegendreFT<S>where
S: StatisticsType,{ /* private fields */ }Expand description
Piecewise Legendre polynomial with Fourier transform capability
This represents a piecewise Legendre polynomial that can be evaluated in the Matsubara frequency domain using Fourier transform.
Implementations
Sourceimpl<S> PiecewiseLegendreFT<S>where
S: StatisticsType,
impl<S> PiecewiseLegendreFT<S>where
S: StatisticsType,
Sourcepub fn new(
poly: PiecewiseLegendrePoly,
_stat: S,
n_asymp: Option<f64>,
) -> Result<PiecewiseLegendreFT<S>, Error>
pub fn new( poly: PiecewiseLegendrePoly, _stat: S, n_asymp: Option<f64>, ) -> Result<PiecewiseLegendreFT<S>, Error>
Create a new PiecewiseLegendreFT from a polynomial and statistics
Arguments
poly- The underlying piecewise Legendre polynomialstat- Statistics type (Fermionic or Bosonic)n_asymp- Asymptotic cutoff frequency index (default: infinity)
Errors
Error::InvalidParameterif the domain ofpolyis not [-1, 1] within 1e-12, orn_asympis NaN or negative (infinity, the default, disables the asymptotic model)
Sourcepub fn get_n_asymp(&self) -> f64
pub fn get_n_asymp(&self) -> f64
Get the asymptotic cutoff frequency index
Sourcepub fn get_statistics(&self) -> Statistics
pub fn get_statistics(&self) -> Statistics
Get the statistics type
Sourcepub fn get_poly(&self) -> &PiecewiseLegendrePoly
pub fn get_poly(&self) -> &PiecewiseLegendrePoly
Get a reference to the underlying polynomial
Sourcepub fn evaluate(&self, omega: &MatsubaraFreq<S>) -> Complex<f64>
pub fn evaluate(&self, omega: &MatsubaraFreq<S>) -> Complex<f64>
Sourcepub fn evaluate_at_n(&self, n: i64) -> Result<Complex<f64>, Error>
pub fn evaluate_at_n(&self, n: i64) -> Result<Complex<f64>, Error>
Evaluate at integer Matsubara index
Errors
Error::InvalidMatsubaraIndex if n has the wrong parity for the
statistics (it returned 0 before)
Sourcepub fn evaluate_at_ns(&self, ns: &[i64]) -> Result<Vec<Complex<f64>>, Error>
pub fn evaluate_at_ns(&self, ns: &[i64]) -> Result<Vec<Complex<f64>>, Error>
Evaluate at multiple Matsubara indices
Errors
The error of Self::evaluate_at_n for the first invalid index