SVEResult

Struct SVEResult 

pub struct SVEResult { /* private fields */ }
Result of Singular Value Expansion computation

Implementations

Source

impl SVEResult

pub fn u(&self) -> &PiecewiseLegendrePolyVector

Left singular functions, one per singular value

pub fn s(&self) -> &[f64]

Singular values, in non-increasing order

pub fn v(&self) -> &PiecewiseLegendrePolyVector

Right singular functions, one per singular value

pub fn epsilon(&self) -> f64

Accuracy the expansion was computed to

pub fn from_discretized_matrix<T>( matrix: &Mat<T>, gauss_x: &Rule<T>, gauss_y: &Rule<T>, segments_x: &[f64], segments_y: &[f64], n_gauss: usize, epsilon: f64, ) -> Result<SVEResult, Error>
where T: CustomNumeric + 'static,

Build an SVE from a kernel matrix discretized on the Gauss points of segments_x x segments_y

matrix[i][j] is sqrt(w_x[i]) * K(x[i], y[j]) * sqrt(w_y[j]) for the piecewise Gauss-Legendre rules gauss_x and gauss_y of n_gauss points per segment, so matrix has n_gauss * n_segments rows and columns. The weights are divided out of the singular vectors before they become piecewise Legendre polynomials.

Errors
pub fn from_discretized_matrices_centrosymmetric( even: &Mat<f64>, odd: &Mat<f64>, gauss_x: &Rule<f64>, gauss_y: &Rule<f64>, segments_x: &[f64], segments_y: &[f64], n_gauss: usize, xmax: f64, ymax: f64, epsilon: f64, ) -> Result<SVEResult, Error>

Self::from_discretized_matrix for a centrosymmetric kernel, whose even and odd parts are discretized on the half domains segments_x x segments_y and extended to [-xmax, xmax] and [-ymax, ymax]

A block of rank 0 (the odd part of a kernel that is even in y, say) contributes no singular function; only both blocks being empty is an error.

Errors
  • The errors of Self::from_discretized_matrix for each block, except that an empty block is accepted
  • The errors of the crate-internal extend_to_full_domain and merge_results, in particular Error::EmptyInput if both blocks are empty
pub fn new( u: PiecewiseLegendrePolyVector, s: Vec<f64>, v: PiecewiseLegendrePolyVector, epsilon: f64, ) -> Result<SVEResult, Error>

Create a new SVEResult

Errors
pub fn part( &self, eps: Option<f64>, max_size: Option<usize>, ) -> Result<(PiecewiseLegendrePolyVector, Vec<f64>, PiecewiseLegendrePolyVector), Error>

Extract a subset of the SVE result based on epsilon and max_size

Arguments
  • eps - Relative threshold for singular values (default: self.epsilon)
  • max_size - Maximum number of singular values to keep
Returns

Tuple of (u_subset, s_subset, v_subset)

Errors