pub enum ArrayRole {
Input,
Output,
}Expand description
Which array of an operation has the wrong shape, in
Error::ShapeMismatch
Variants
Input
An array that the operation reads, e.g. the coefficients of an evaluation or a given sampling matrix
Output
The array that the operation writes to, e.g. out of evaluate_nd_to